@@ -239,7 +239,7 @@ class XapianSearchBackend(BaseSearchBackend):
         self._update_cache()
         return self._columns
 
-    def update(self, index, iterable):
+    def update(self, index, iterable, commit=True):
         """
         Updates the `index` with any objects in `iterable` by adding/updating
         the database as needed.
@@ -247,6 +247,8 @@ class XapianSearchBackend(BaseSearchBackend):
         Required arguments:
             `index` -- The `SearchIndex` to process
             `iterable` -- An iterable of model instances to index
+        Optional arguments:
+            `commit` -- ignored
 
         For each object in `iterable`, a document is created containing all
         of the terms extracted from `index.full_prepare(obj)` with field prefixes,
@@ -492,12 +494,15 @@ class XapianSearchBackend(BaseSearchBackend):
         finally:
             database.close()
 
-    def remove(self, obj):
+    def remove(self, obj, commit=True):
         """
         Remove indexes for `obj` from the database.
 
         We delete all instances of `Q<app_name>.<model_name>.<pk>` which
         should be unique to this object.
+
+        Optional arguments:
+           `commit` -- ignored
         """
         database = self._database(writable=True)
         database.delete_document(TERM_PREFIXES[ID] + get_identifier(obj))
